FeatureManagementInstruction

Enum FeatureManagementInstruction 

pub enum FeatureManagementInstruction {
    Upsert {
        name: String,
        start_time: u64,
        end_time: u64,
    },
    UpdateAuthority {
        new_authority: Pubkey,
    },
}
Instructions supported by the Feature Management Program

Variants



Upsert

Upsert features (add or modify)

This instruction requires a valid signature from the authority.

Accounts expected: 0. [writable] Storage account (PDA)

  1. [signer] The authority account

Fields

name: String

Name of the feature

start_time: u64

Start time (Unix timestamp in seconds)

end_time: u64

End time (Unix timestamp in seconds)



UpdateAuthority

Update the authority

This instruction requires a valid signature from the current authority.

Accounts expected: 0. [writable] Storage account (PDA)

  1. [signer] The current authority account

Fields

new_authority: Pubkey

The new authority that will control the feature management system

Implementations

Source

impl FeatureManagementInstruction

pub fn serialize(&self) -> Result<Vec<u8>, Error>

Serialize instruction data

pub fn deserialize(data: &[u8]) -> Result<Self, Error>

Deserialize instruction data