pub enum FeatureManagementInstruction {
Upsert {
name: String,
start_time: u64,
end_time: u64,
},
UpdateAuthority {
new_authority: Pubkey,
},
}Expand description
Instructions supported by the Feature Management Program
Variants
Upsert
Upsert features (add or modify)
This instruction requires a valid signature from the authority.
Accounts expected:
0. [writable] Storage account (PDA)
[signer]The authority account
Fields
UpdateAuthority
Update the authority
This instruction requires a valid signature from the current authority.
Accounts expected:
0. [writable] Storage account (PDA)
[signer]The current authority account
Fields
The new authority that will control the feature management system
Implementations